@@ -1,7 +1,6 @@
 package Terse::Plugin::Config;
 
 use base 'Terse::Plugin';
-use JSON;
 use Data::LNPath qw/lnpath/;
 
 sub build_plugin {
@@ -10,7 +9,7 @@ sub build_plugin {
 		my $file = $0;
 		($self->config_file = $0) =~ s/(\.psgi)?$/.json/;
 	}
-	$self->{data} = $self->_read_file($self->config_file);
+	$self->data = $self->_read_file($self->config_file);
 	return $self;
 }
 
@@ -29,7 +28,7 @@ sub _read_file {
 
 sub _parse_config {
 	my ($self, $content) = @_;
-	return JSON->new->decode($content);
+	return $self->graft('data', $content);
 }
 
 1;
@@ -42,7 +41,7 @@ Terse::Plugin::Config - JSON configs
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
