@@ -10,7 +10,7 @@ sub build_plugin {
 		my $file = $0;
 		($self->config_file = $0) =~ s/(\.psgi)?$/.yml/;
 	}
-	$self->{data} = LoadFile $self->config_file;
+	$self->data = LoadFile $self->config_file;
 	return $self;
 }
 
@@ -24,7 +24,7 @@ Terse::Plugin::Config::YAML - YAML configs
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
